@@ -78,6 +78,13 @@ def main(*args, **keywords):
     cl_core_port = ob.GetInteger('cl_core_port')
     file_logger = None
 
+    # создать симлинки на команды
+    if not args.method and args.create_symlink:
+        from func import create_symlink, initialization
+        initialization(cl_wsdl)
+        create_symlink(local_data_path, data_path)
+        return 0
+
     if args.version:
         print cl_ver
         return 0
@@ -197,11 +204,6 @@ def main(*args, **keywords):
     App = ClApplication([CombinedServerClass],'tns', log = file_logger)
     tc = App.get_service(CombinedServerClass)
 
-    if args.create_symlink:
-        from func import create_symlink
-        create_symlink(local_data_path,data_path)
-        return 0
-
     # delete all sid and pid informations file
     cert_cmd.create_path(data_path, certbase, rights, group_rights,local_data_path)
 
