@@ -495,7 +495,9 @@ class OpenSSLAdapter (pyOpenSSLAdapter):
     def get_context(self):
         """Return an SSL.Context from self attributes."""
         # See http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/442473
-        c = OpenSSL.SSL.Context(OpenSSL.SSL.SSLv23_METHOD)
+        c = OpenSSL.SSL.Context(OpenSSL.SSL.TLSv1_2_METHOD)
+        c.set_options(OpenSSL.SSL.OP_NO_SSLv2 | OpenSSL.SSL.OP_NO_SSLv3)
+
         #c.set_passwd_cb(lambda *unused: 'qqqq')
         c.use_privatekey_file(self.private_key)
         c.set_verify(OpenSSL.SSL.VERIFY_PEER, self.verify_func)
