@@ -150,7 +150,7 @@ class UpdateConfigs(UpdateLogger):
 
     def updateDesktopConfig(self,nameProgram,version,slot,category,configPath,
                            rootSet,verbose,dispatchConf,templates_locate,
-                           ebuildPhase, useClt):
+                           ebuildPhase, useClt, arch_machine):
         """
         Настроить пакеты в профилях пользователей
         """
@@ -178,6 +178,7 @@ class UpdateConfigs(UpdateLogger):
                 clVars.Set("cl_verbose_set", verbose, True)
                 clVars.Set("cl_protect_use_set", "off", True)
                 clVars.Set("cl_template_path_use", templates_locate, True)
+                clVars.Set("install.os_install_arch_machine", arch_machine, True)
 
                 self._setClMergePkg(clVars,category,nameProgram)
 
@@ -206,7 +207,7 @@ class UpdateConfigs(UpdateLogger):
 
     def updateSystemConfig(self,nameProgram,version,slot,category,configPath,
                            rootSet,verbose,dispatchConf,templates_locate,
-                           ebuildPhase, useClt):
+                           ebuildPhase, useClt, arch_machine):
         """
         Обновить конфигурационные файлы системы
         """
@@ -235,6 +236,7 @@ class UpdateConfigs(UpdateLogger):
             clVars.Set("cl_dispatch_conf", dispatchConf, True)
             clVars.Set("cl_template_path_use", templates_locate, True)
             clVars.Set("core.cl_core_pkg_slot", slot, True)
+            clVars.Set("install.os_install_arch_machine", arch_machine, True)
             useClt = useClt in (True,"on")
 
             dictVer = {slot:version}
@@ -270,11 +272,12 @@ class UpdateConfigs(UpdateLogger):
             self.endTask()
         return True
 
-    def patchPackage(self,configPath,nameProgram):
+    def patchPackage(self,configPath,nameProgram, arch_machine):
         """
         Наложить патчи на пакет
         """
         self.clVars.Set("cl_root_path", configPath, True)
+        self.clVars.Set("install.os_install_arch_machine", arch_machine, True)
         clTempl = ChainProgressTemplate( self.startTask,
                            self.endTask,
                            self.setProgress,
@@ -329,75 +332,3 @@ class UpdateConfigs(UpdateLogger):
         time.sleep(1)
         os.system('/etc/init.d/%s restart &>/dev/null &'%service_name)
         return True
-
-class PackageUpdater(UpdateConfigs): #,updateUserConfigs):
-    def __init__(self):
-        self.clVars = None
-        self.clTempl = None
-
-    def initVars(self,datavars=None):
-        """Primary variables initialization"""
-        if not datavars:
-            self.clVars = DataVars()
-            self.clVars.importData()
-            self.clVars.flIniFile()
-        else:
-            self.clVars = datavars
-
-    def closeClTemplate(self):
-        if self.clTempl:
-            if self.clTempl.cltObj:
-                self.clTempl.cltObj.closeFiles()
-            self.clTempl.closeFiles()
-            self.clTempl = None
-
-    def postAction(self,error):
-        """
-        Post action for umount user res and write status_sync=error
-        """
-        self.closeClTemplate()
-        return True
-
-
-    def updateConfig(self):
-        if not os.path.exists('/etc/calculate/calculate.env') and \
-            not (dv.Get('cl_core_pkg_name') in ('calculate-utilities',
-                                                'calculate-utils',
-                                                'calculate-install') and
-                 getTupleVersion(dv.Get('cl_core_pkg_version')) >=
-                 getTupleVersion("3.1.0_alpha4")):
-            self.printWARNING(
-                _("Configuration skipping until "
-                  "calculate-utils are updated"))
-            return True
-        self.initVars(dv)
-        clVars = DataVars()
-        clVars.importData()
-        clVars.flIniFile()
-        slot = dv.Get('cl_core_pkg_slot')
-        version = dv.Get('cl_core_pkg_version')
-        category = dv.Get('cl_core_pkg_category')
-        nameProgram = dv.Get('cl_core_pkg_name')
-        # define that category/nameProgram installed
-        if dv.Get('cl_ebuild_phase') in ('prerm','postrm'):
-            version = ""
-        dictVer = {slot:version}
-        cl_template.templateFunction.installProg.update(\
-                    {"%s/%s"%(category,nameProgram):dictVer,
-                        "%s"%(nameProgram):dictVer})
-        try:
-            if os.environ.get("EBUILD_PHASE",""):
-                clVars.raiseVariableNotFound = \
-                    lambda name,*args,**kwargs: StubVariable(*args,
-                                                             **kwargs)
-                clVars.raiseModuleError = \
-                    lambda name,*args,**kwargs: False
-            if dv.Get('cl_core_pkg_system_set') == 'on':
-                self.updateSystemConfig(dv,clVars)
-            if dv.Get('cl_core_pkg_desktop_set') == 'on' and \
-                not dv.Get('cl_ebuild_phase') in ("preinst","prerm"):
-                self.updateDesktopConfig(dv,clVars)
-        finally:
-            if clVars:
-                clVars.close()
-        return True
